==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/be.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Кіраванне Параметры Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "кіраванне Галерэя");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Поўнапамерныя Шырыня выявы");
define('MANAGE_GALLERY_FULL_HEIGHT', "павялічыць Вышыня");
define('MANAGE_GALLERY_THUMB_WIDTH', "Эскіз Шырыня выявы");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Эскіз Вышыня выявы");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Запаведнік Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "паказаць Назвы");
define('MANAGE_GALLERY_DISABLE_SORT', "адключыць Сартаваць");
define('MANAGE_GALLERY_DELETE_IMAGE', "выдаліць выява");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "захаваць сартаванне");
define('MANAGE_GALLERY_PUBLISH_MSG', "Націсніце кнопку &quot;Абнавіць&quot;, каб апублікаваць <br /> вашы загружаныя выявы.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Усе выявы былі зменены і налады былі захаваныя.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Быў памылка змены памеру малюнка або захавання налад.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ваш лад (ы) былі ўкладзены.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Быў Памылка пры загрузцы малюнка (ы).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Файл, які вы ўкладаеце, не з&#39;яўляецца выявай.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Файл, які вы ўкладаеце занадта вялікі.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Назва была захавана.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Вы ўпэўненыя, што хочаце выдаліць малюнак");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Выява было выдаленае.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Быў памылка выдалення малюнка.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Захаванне параметраў і змяненне памераў малюнкаў, калі ласка, пачакайце ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Загрузка, пачакайце калі ласка ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Парадак сартавання ня быў захаваны. Вы хочаце, каб захаваць парадак сартавання?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Парадак сартавання малюнкаў захаваны.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Быў памылка пры захаванні роду малюнка.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/be.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Кіраванне Параметры Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "кіраванне Галерэя");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Поўнапамерныя Шырыня выявы");
define('MANAGE_GALLERY_FULL_HEIGHT', "павялічыць Вышыня");
define('MANAGE_GALLERY_THUMB_WIDTH', "Эскіз Шырыня выявы");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Эскіз Вышыня выявы");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Запаведнік Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "паказаць Назвы");
define('MANAGE_GALLERY_DISABLE_SORT', "адключыць Сартаваць");
define('MANAGE_GALLERY_DELETE_IMAGE', "выдаліць выява");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "захаваць сартаванне");
define('MANAGE_GALLERY_PUBLISH_MSG', "Націсніце кнопку &quot;Абнавіць&quot;, каб апублікаваць <br /> вашы загружаныя выявы.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Усе выявы былі зменены і налады былі захаваныя.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Быў памылка змены памеру малюнка або захавання налад.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Ваш лад (ы) былі ўкладзены.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Быў Памылка пры загрузцы малюнка (ы).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Файл, які вы ўкладаеце, не з&#39;яўляецца выявай.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Файл, які вы ўкладаеце занадта вялікі.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Назва была захавана.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Вы ўпэўненыя, што хочаце выдаліць малюнак");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Выява было выдаленае.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Быў памылка выдалення малюнка.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Захаванне параметраў і змяненне памераў малюнкаў, калі ласка, пачакайце ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Загрузка, пачакайце калі ласка ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Парадак сартавання ня быў захаваны. Вы хочаце, каб захаваць парадак сартавання?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Парадак сартавання малюнкаў захаваны.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Быў памылка пры захаванні роду малюнка.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Файл, які вы спрабуеце загрузіць, перавышае налады PHP &quot;upload_max_filesize&quot; або &quot;post_max_size&quot;. Каб павялічыць гэтыя ліміты, звяжыцеся са сваім сістэмным адміністратарам.");
?>
